@@ -38,7 +38,6 @@ class Challenger(OpenID):
         if usersign.startswith('http'):
             usersign = usersign.split('://', 1)[1]
         usersign = usersign.rstrip('/')
-
         redirect = environ['tiddlyweb.query'].get(
             'tiddlyweb_redirect', ['/'])[0]
         uri = urlparse.urljoin(server_host_url(environ), redirect)
@@ -51,10 +50,12 @@ class Challenger(OpenID):
             fragment = None
         secondary_cookie_name = 'tiddlyweb_secondary_user'
         secondary_cookie_age = None
+        secondary_cookie_only = False
         if fragment:
             openid = fragment[len(FRAGMENT_PREFIX):]
             uri = uri.replace(FRAGMENT_PREFIX + openid,
                     FRAGMENT_PREFIX + usersign)
+            secondary_cookie_only = True
 
         secret = environ['tiddlyweb.config']['secret']
         cookie_header_string = make_cookie(cookie_name, usersign,
@@ -63,9 +64,11 @@ class Challenger(OpenID):
         secondary_cookie_header_string = make_cookie(secondary_cookie_name, usersign,
                 mac_key=secret, path=self._cookie_path(environ),
                 expires=cookie_age, domain=self._domain_path(environ))
-        start_response('303 See Other',
-                [('Location', uri.encode('utf-8')),
+        headers = [('Location', uri.encode('utf-8')),
                     ('Content-Type', 'text/plain'),
-                    ('Set-Cookie', secondary_cookie_header_string),
-                    ('Set-Cookie', cookie_header_string)])
+                    ('Set-Cookie', secondary_cookie_header_string)]
+        if not secondary_cookie_only:
+          headers.append(('Set-Cookie', cookie_header_string))
+
+        start_response('303 See Other', headers)
         return [uri]
